<?php
/**
 * Laundry Lite Theme Customizer
 *
 * @package Laundry Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function laundry_lite_customize_register( $wp_customize ) {
	
	function laundry_lite_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}
	
	$wp_customize->get_setting( 'blogname' )->tranport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->tranport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
	    'selector' => 'h1.site-title',
	    'render_callback' => 'laundry_lite_customize_partial_blogname',
	) );

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
	    'selector' => 'p.site-description',
	    'render_callback' => 'laundry_lite_customize_partial_blogdescription',
	) );
	
	/***************************************
	** Color Scheme
	***************************************/
	$wp_customize->add_setting('color_scheme', array(
		'default' => '#1f2230',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));

	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'color_scheme',array(
			'label' => __('Color Scheme','laundry-lite'),
			'description' => __('Select color from here.','laundry-lite'),
			'section' => 'colors',
			'settings' => 'color_scheme'
		))
	);
	
	$wp_customize->add_setting('sub_color_scheme', array(
		'default' => '#ff662a',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));

	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'sub_color_scheme',array(
			'label' => __('Color Scheme','laundry-lite'),
			'description' => __('Select color from here.','laundry-lite'),
			'section' => 'colors',
			'settings' => 'sub_color_scheme'
		))
	);

	$wp_customize->add_setting('laun_headerbg_color', array(
		'default' => '#ffffff',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));

	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'laun_headerbg_color',array(
			'label' => __('Header Background color','laundry-lite'),
			'description'	=> __('Select background color for header.','laundry-lite'),
			'section' => 'colors',
			'settings' => 'laun_headerbg_color'
		))
	);

	$wp_customize->add_setting('laun_footer_color', array(
		'default' => '#ff662a',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));

	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'laun_footer_color',array(
			'label' => __('Footer Background Color','laundry-lite'),
			'description' => __('Select background color for footer.','laundry-lite'),
			'section' => 'colors',
			'settings' => 'laun_footer_color'
		))
	);

	/***************************************
	** Registerd Theme Setup Panel
	***************************************/
	$wp_customize->add_panel( 'laun_theme_panel',
		array(
			'title'            => __( 'Theme Setup', 'laundry-lite' ),
			'description'      => __( 'Theme Modifications like color scheme, header info, slider and sections can be done here', 'laundry-lite' ),
		)
	);
	
	/***************************************
	** Header Info
	***************************************/
	$wp_customize->add_section(
		'laun_head_info',
		array(
			'title' => __('Header Information', 'laundry-lite'),
			'priority' => null,
			'description'	=> __('Add header information here. <strong>Use font-awesome version 4.7</strong>','laundry-lite'),
			'panel' => 'laun_theme_panel',
		)
	);
	
	$wp_customize->add_setting('laun_head_icn1',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('laun_head_icn1',array(
		'type'	=> 'text',
		'label'	=> __('Add font Awesome icon name here for first box','laundry-lite'),
		'section'	=> 'laun_head_info'
	));
	
	$wp_customize->add_setting('laun_head_sub1',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('laun_head_sub1',array(
		'type'	=> 'text',
		'label'	=> __('Add heading here for first box','laundry-lite'),
		'section'	=> 'laun_head_info'
	));
	
	$wp_customize->add_setting('laun_head_main1',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('laun_head_main1',array(
		'type'	=> 'text',
		'label'	=> __('Add text here for first box','laundry-lite'),
		'section'	=> 'laun_head_info'
	));
	
	$wp_customize->add_setting('laun_head_icn2',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('laun_head_icn2',array(
		'type'	=> 'text',
		'label'	=> __('Add font Awesome icon name here for second box','laundry-lite'),
		'section'	=> 'laun_head_info'
	));
	
	$wp_customize->add_setting('laun_head_sub2',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('laun_head_sub2',array(
		'type'	=> 'text',
		'label'	=> __('Add heading here for second box','laundry-lite'),
		'section'	=> 'laun_head_info'
	));
	
	$wp_customize->add_setting('laun_head_main2',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('laun_head_main2',array(
		'type'	=> 'text',
		'label'	=> __('Add text here for second box','laundry-lite'),
		'section'	=> 'laun_head_info'
	));
	
	$wp_customize->add_setting('laun_head_icn3',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('laun_head_icn3',array(
		'type'	=> 'text',
		'label'	=> __('Add font Awesome icon name here for third box','laundry-lite'),
		'section'	=> 'laun_head_info'
	));
	
	$wp_customize->add_setting('laun_head_sub3',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('laun_head_sub3',array(
		'type'	=> 'text',
		'label'	=> __('Add heading here for third box','laundry-lite'),
		'section'	=> 'laun_head_info'
	));
	
	$wp_customize->add_setting('laun_head_main3',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('laun_head_main3',array(
		'type'	=> 'text',
		'label'	=> __('Add text here for third box','laundry-lite'),
		'section'	=> 'laun_head_info'
	));
	
	$wp_customize->selective_refresh->add_partial('laun_head_icn3', array(
        'selector' => '.header-info'
    ));
	
	$wp_customize->add_setting('laun_hide_headinfo',array(
		'default' => true,
		'sanitize_callback' => 'laundry_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 

	$wp_customize->add_control( 'laun_hide_headinfo', array(
	   'settings' => 'laun_hide_headinfo',
	   'section'   => 'laun_head_info',
	   'label'     => __('Check this to hide Header information.','laundry-lite'),
	   'type'      => 'checkbox'
	));
	
	/***************************************
	** Header Button
	***************************************/
	$wp_customize->add_section(
		'laun_cta_btn',
		array(
			'title' => __('CTA Button', 'laundry-lite'),
			'priority' => null,
			'description'	=> __('Add text and link for header cta button','laundry-lite'),
			'panel' => 'laun_theme_panel',
		)
	);

	$wp_customize->add_setting('laun_cta_lbl',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('laun_cta_lbl',array(
		'type'	=> 'text',
		'label'	=> __('Add header cta button text here','laundry-lite'),
		'section'	=> 'laun_cta_btn'
	));

	$wp_customize->add_setting('laun_cta_link',array(
		'sanitize_callback'	=> 'esc_url_raw'
	));

	$wp_customize->add_control('laun_cta_link',array(
		'type'	=> 'url',
		'label'	=> __('Add header cta button link here.','laundry-lite'),
		'section'	=> 'laun_cta_btn'
	));
	$wp_customize->selective_refresh->add_partial('laun_cta_lbl', array(
        'selector' => '.header-btn a'
    ));
	
	/***************************************
	** Slider Section
	***************************************/
	$wp_customize->add_section(
		'laun_theme_slider',
		array(
			'title' => __('Theme Slider', 'laundry-lite'),
			'priority' => null,
			'description'	=> __('Recommended image size (1600x900). Slider will work only when you select the static front page.','laundry-lite'),
			'panel' => 'laun_theme_panel',
		)
	);

	$wp_customize->add_setting('slide1',array(
			'default' => '0',
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('slide1',array(
			'type'	=> 'dropdown-pages',
			'label'	=> __('Select page for slide one:','laundry-lite'),
			'section'	=> 'laun_theme_slider'
	));

	$wp_customize->add_setting('slide2',array(
			'default' => '0',
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('slide2',array(
			'type'	=> 'dropdown-pages',
			'label'	=> __('Select page for slide two:','laundry-lite'),
			'section'	=> 'laun_theme_slider'
	));

	$wp_customize->add_setting('slide3',array(
			'default' => '0',
			'capability' => 'edit_theme_options',
			'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('slide3',array(
			'type'	=> 'dropdown-pages',
			'label'	=> __('Select page for slide three:','laundry-lite'),
			'section'	=> 'laun_theme_slider'
	));

	$wp_customize->add_setting('slide_more',array(
		'default'	=> __('Read More','laundry-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('slide_more',array(
		'label'	=> __('Add slider link button text.','laundry-lite'),
		'section'	=> 'laun_theme_slider',
		'setting'	=> 'slide_more',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('laun_hide_slider',array(
		'default' => true,
		'sanitize_callback' => 'laundry_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	)); 

	$wp_customize->add_control( 'laun_hide_slider', array(
	   'settings' => 'laun_hide_slider',
	   'section'   => 'laun_theme_slider',
	   'label'     => __('Check this to hide slider.','laundry-lite'),
	   'type'      => 'checkbox'
	));
	
	/***************************************
	** Social Icon
	***************************************/
	$wp_customize->add_section(
		'laun_sclicn',
		array(
			'title' => __('Social Icons', 'laundry-lite'),
			'priority' => null,
			'description'	=> __('Add your social media account link here.','laundry-lite'),
			'panel' => 'laun_theme_panel',
		)
	);
	
	$wp_customize->add_setting('laun_sclicn_ttl',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('laun_sclicn_ttl',array(
		'type'	=> 'text',
		'label'	=> __('Add title here','laundry-lite'),
		'section'	=> 'laun_sclicn'
	));

	$wp_customize->add_setting('laun_sclicn_fb',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));

	$wp_customize->add_control('laun_sclicn_fb',array(
		'type'	=> 'text',
		'label'	=> __('Add facebook account link here','laundry-lite'),
		'section'	=> 'laun_sclicn'
	));
	
	$wp_customize->add_setting('laun_sclicn_tw',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));

	$wp_customize->add_control('laun_sclicn_tw',array(
		'type'	=> 'text',
		'label'	=> __('Add twitter account link here','laundry-lite'),
		'section'	=> 'laun_sclicn'
	));
	
	$wp_customize->add_setting('laun_sclicn_ins',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));

	$wp_customize->add_control('laun_sclicn_ins',array(
		'type'	=> 'text',
		'label'	=> __('Add instagram account link here','laundry-lite'),
		'section'	=> 'laun_sclicn'
	));
	
	$wp_customize->add_setting('laun_sclicn_gp',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));

	$wp_customize->add_control('laun_sclicn_gp',array(
		'type'	=> 'text',
		'label'	=> __('Add google plus account link here','laundry-lite'),
		'section'	=> 'laun_sclicn'
	));
	
	$wp_customize->add_setting('laun_sclicn_yt',array(
		'sanitize_callback'	=> 'wp_filter_nohtml_kses',
	));

	$wp_customize->add_control('laun_sclicn_yt',array(
		'type'	=> 'text',
		'label'	=> __('Add youtube account link here','laundry-lite'),
		'section'	=> 'laun_sclicn'
	));
	
	$wp_customize->selective_refresh->add_partial('laun_sclicn_ttl', array(
        'selector' => '.social-bar .social-bar-left'
    ));
	
	$wp_customize->add_setting('laun_hide_sclicn',array(
		'default' => true,
		'sanitize_callback' => 'laundry_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'laun_hide_sclicn', array(
	   'settings' => 'laun_hide_sclicn',
	   'section'   => 'laun_sclicn',
	   'label'     => __('Check this to hide social icon strip below slider.','laundry-lite'),
	   'type'      => 'checkbox'
	));
	
	/***************************************
	** About Section
	***************************************/
	$wp_customize->add_section(
		'laun_intro_sec',
		array(
			'title' => __('About us Section', 'laundry-lite'),
			'priority' => null,
			'description'	=> __('Select page for homepage first section. This section will be displayed only when you select the static front page.','laundry-lite'),
			'panel' => 'laun_theme_panel',
		)
	);
	
	$wp_customize->add_setting('laun_intro_ttl',array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'transport' => 'refresh'
	));
	
	$wp_customize->add_control('laun_intro_ttl',array(
		'type'	=> 'text',
		'label'	=> __('Add Section Sub Title Here','laundry-lite'),
		'section'	=> 'laun_intro_sec'
	));
	
	$wp_customize->add_setting('laun_intro',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('laun_intro',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for display first section','laundry-lite'),
		'section'	=> 'laun_intro_sec'
	));
	
	$wp_customize->selective_refresh->add_partial('laun_intro', array(
        'selector' => '.intro-content'
    ));
	
	$wp_customize->add_setting('intro_more',array(
		'default'	=> __('Read More','laundry-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('intro_more',array(
		'label'	=> __('Add read more button text.','laundry-lite'),
		'section'	=> 'laun_intro_sec',
		'setting'	=> 'intro_more',
		'type'	=> 'text'
	));
	
	$wp_customize->add_setting('laun_hide_intro',array(
		'default' => true,
		'sanitize_callback' => 'laundry_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'laun_hide_intro', array(
	   'settings' => 'laun_hide_intro',
	   'section'   => 'laun_intro_sec',
	   'label'     => __('Check this to hide first section.','laundry-lite'),
	   'type'      => 'checkbox'
	));
	
	/***************************************
	** Services Section
	***************************************/
	$wp_customize->add_section(
		'laun_ser_sec',
		array(
			'title' => __('Services Section', 'laundry-lite'),
			'priority' => null,
			'description'	=> __('Select pages for homepage second section. This section will be displayed only when you select the static front page.','laundry-lite'),
			'panel' => 'laun_theme_panel',
		)
	);

	$wp_customize->add_setting('laun_ser_ttl',array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('laun_ser_ttl',array(
		'type'	=> 'text',
		'label'	=> __('Add Section Title Here','laundry-lite'),
		'section'	=> 'laun_ser_sec'
	));

	$wp_customize->selective_refresh->add_partial('laun_ser_ttl', array(
		'selector' => '.welcome-section h2.section_title'
	));

	$wp_customize->add_setting('ser1',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('ser1',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for first column','laundry-lite'),
		'section'	=> 'laun_ser_sec'
	));

	$wp_customize->add_setting('ser2',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('ser2',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for second column','laundry-lite'),
		'section'	=> 'laun_ser_sec'
	));

	$wp_customize->add_setting('ser3',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('ser3',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for third column','laundry-lite'),
		'section'	=> 'laun_ser_sec'
	));

	$wp_customize->add_setting('laun_hide_ser',array(
		'default' => true,
		'sanitize_callback' => 'laundry_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));

	$wp_customize->add_control( 'laun_hide_ser', array(
	   'settings' => 'laun_hide_ser',
	   'section'   => 'laun_ser_sec',
	   'label'     => __('Check this to hide service section.','laundry-lite'),
	   'type'      => 'checkbox'
	));
}
add_action( 'customize_register', 'laundry_lite_customize_register' );

function laundry_lite_css_func(){ ?>
<style>
	#header{
		background-color:<?php echo esc_attr(get_theme_mod('laun_headerbg_color','#ffffff')); ?>;
	}
	a,
	.tm_client strong,
	.postmeta a:hover,
	.blog-post h3.entry-title,
	a.blog-more:hover,
	#commentform input#submit,
	input.search-submit,
	.blog-date .date,
	.sitenav ul li.current_page_item a,
	.sitenav ul li a:hover,
	.sitenav ul li.current_page_item ul li a:hover,
	h2.section_title{
		color:<?php echo esc_attr(get_theme_mod('color_scheme','#1f2230'));?>;
	}
	h3.widget-title,
	.nav-links .current,
	.nav-links a:hover,
	p.form-submit input[type="submit"],
	.nivo-controlNav a,
	.header-info-icon,
	.header-btn a,
	.laun-slider .inner-caption .sliderbtn:hover,
	.social-bar,
	.read-more a,
	.service-more a{
		background-color:<?php echo esc_attr(get_theme_mod('color_scheme','#1f2230')); ?>;
	}
	a:hover,
	p.site-description,
	.header-info-text h5,
	h4.section_sub_title,
	#sidebar ul li a:hover{
		color:<?php echo esc_attr(get_theme_mod('sub_color_scheme','#ff662a')); ?>;
	}
	#navigation,
	.sitenav ul li.menu-item-has-children:hover > ul,
	.sitenav ul li.menu-item-has-children:focus > ul,
	.sitenav ul li.menu-item-has-children.focus > ul,
	.laun-slider .inner-caption .sliderbtn,
	.read-more a:hover,
	.service-more a:hover,
	.nivo-controlNav a.active{
		background-color:<?php echo esc_attr(get_theme_mod('sub_color_scheme','#ff662a')); ?>;
	}
	.copyright-wrapper{
		background-color:<?php echo esc_attr(get_theme_mod('laun_footer_color','#ff662a')); ?>;
	}
</style>
<?php }
add_action('wp_head','laundry_lite_css_func');

function laundry_lite_customize_preview_js() {
	wp_enqueue_script( 'laundry-lite-customize-preview', get_template_directory_uri() . '/js/customize-preview.js', array( 'customize-preview' ), '20141216', true );
}
add_action( 'customize_preview_init', 'laundry_lite_customize_preview_js' );